# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: substrait/plan.proto
# Protobuf Python Version: 5.29.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    5,
    '',
    'substrait/plan.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from substrait import algebra_pb2 as substrait_dot_algebra__pb2
from substrait.extensions import extensions_pb2 as substrait_dot_extensions_dot_extensions__pb2
from substrait import type_pb2 as substrait_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14substrait/plan.proto\x12\tsubstrait\x1a\x17substrait/algebra.proto\x1a%substrait/extensions/extensions.proto\x1a\x14substrait/type.proto\"c\n\x07PlanRel\x12\"\n\x03rel\x18\x01 \x01(\x0b\x32\x0e.substrait.RelH\x00R\x03rel\x12(\n\x04root\x18\x02 \x01(\x0b\x32\x12.substrait.RelRootH\x00R\x04rootB\n\n\x08rel_type\"\xf2\x04\n\x04Plan\x12,\n\x07version\x18\x06 \x01(\x0b\x32\x12.substrait.VersionR\x07version\x12S\n\x0e\x65xtension_uris\x18\x01 \x03(\x0b\x32(.substrait.extensions.SimpleExtensionURIB\x02\x18\x01R\rextensionUris\x12O\n\x0e\x65xtension_urns\x18\x08 \x03(\x0b\x32(.substrait.extensions.SimpleExtensionURNR\rextensionUrns\x12P\n\nextensions\x18\x02 \x03(\x0b\x32\x30.substrait.extensions.SimpleExtensionDeclarationR\nextensions\x12\x30\n\trelations\x18\x03 \x03(\x0b\x32\x12.substrait.PlanRelR\trelations\x12X\n\x13\x61\x64vanced_extensions\x18\x04 \x01(\x0b\x32\'.substrait.extensions.AdvancedExtensionR\x12\x61\x64vancedExtensions\x12,\n\x12\x65xpected_type_urls\x18\x05 \x03(\tR\x10\x65xpectedTypeUrls\x12Q\n\x12parameter_bindings\x18\x07 \x03(\x0b\x32\".substrait.DynamicParameterBindingR\x11parameterBindings\x12\x37\n\x0ctype_aliases\x18\t \x03(\x0b\x32\x14.substrait.TypeAliasR\x0btypeAliases\";\n\x0bPlanVersion\x12,\n\x07version\x18\x06 \x01(\x0b\x32\x12.substrait.VersionR\x07version\"\xa9\x01\n\x07Version\x12!\n\x0cmajor_number\x18\x01 \x01(\rR\x0bmajorNumber\x12!\n\x0cminor_number\x18\x02 \x01(\rR\x0bminorNumber\x12!\n\x0cpatch_number\x18\x03 \x01(\rR\x0bpatchNumber\x12\x19\n\x08git_hash\x18\x04 \x01(\tR\x07gitHash\x12\x1a\n\x08producer\x18\x05 \x01(\tR\x08producer\"y\n\x17\x44ynamicParameterBinding\x12)\n\x10parameter_anchor\x18\x01 \x01(\rR\x0fparameterAnchor\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32\x1d.substrait.Expression.LiteralR\x05valueBf\n\x12io.substrait.protoP\x01Z9github.com/substrait-io/substrait-protobuf/go/substraitpb\xaa\x02\x12Substrait.Protobufb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'substrait.plan_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022io.substrait.protoP\001Z9github.com/substrait-io/substrait-protobuf/go/substraitpb\252\002\022Substrait.Protobuf'
  _globals['_PLAN'].fields_by_name['extension_uris']._loaded_options = None
  _globals['_PLAN'].fields_by_name['extension_uris']._serialized_options = b'\030\001'
  _globals['_PLANREL']._serialized_start=121
  _globals['_PLANREL']._serialized_end=220
  _globals['_PLAN']._serialized_start=223
  _globals['_PLAN']._serialized_end=849
  _globals['_PLANVERSION']._serialized_start=851
  _globals['_PLANVERSION']._serialized_end=910
  _globals['_VERSION']._serialized_start=913
  _globals['_VERSION']._serialized_end=1082
  _globals['_DYNAMICPARAMETERBINDING']._serialized_start=1084
  _globals['_DYNAMICPARAMETERBINDING']._serialized_end=1205
# @@protoc_insertion_point(module_scope)
