# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: substrait/extensions/extensions.proto
# Protobuf Python Version: 5.29.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    5,
    '',
    'substrait/extensions/extensions.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%substrait/extensions/extensions.proto\x12\x14substrait.extensions\x1a\x19google/protobuf/any.proto\"\\\n\x12SimpleExtensionURI\x12\x30\n\x14\x65xtension_uri_anchor\x18\x01 \x01(\rR\x12\x65xtensionUriAnchor\x12\x10\n\x03uri\x18\x02 \x01(\tR\x03uri:\x02\x18\x01\"X\n\x12SimpleExtensionURN\x12\x30\n\x14\x65xtension_urn_anchor\x18\x01 \x01(\rR\x12\x65xtensionUrnAnchor\x12\x10\n\x03urn\x18\x02 \x01(\tR\x03urn\"\xe9\x07\n\x1aSimpleExtensionDeclaration\x12g\n\x0e\x65xtension_type\x18\x01 \x01(\x0b\x32>.substrait.extensions.SimpleExtensionDeclaration.ExtensionTypeH\x00R\rextensionType\x12\x83\x01\n\x18\x65xtension_type_variation\x18\x02 \x01(\x0b\x32G.substrait.extensions.SimpleExtensionDeclaration.ExtensionTypeVariationH\x00R\x16\x65xtensionTypeVariation\x12s\n\x12\x65xtension_function\x18\x03 \x01(\x0b\x32\x42.substrait.extensions.SimpleExtensionDeclaration.ExtensionFunctionH\x00R\x11\x65xtensionFunction\x1a\xb8\x01\n\rExtensionType\x12:\n\x17\x65xtension_uri_reference\x18\x01 \x01(\rB\x02\x18\x01R\x15\x65xtensionUriReference\x12\x36\n\x17\x65xtension_urn_reference\x18\x04 \x01(\rR\x15\x65xtensionUrnReference\x12\x1f\n\x0btype_anchor\x18\x02 \x01(\rR\ntypeAnchor\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x1a\xd4\x01\n\x16\x45xtensionTypeVariation\x12:\n\x17\x65xtension_uri_reference\x18\x01 \x01(\rB\x02\x18\x01R\x15\x65xtensionUriReference\x12\x36\n\x17\x65xtension_urn_reference\x18\x04 \x01(\rR\x15\x65xtensionUrnReference\x12\x32\n\x15type_variation_anchor\x18\x02 \x01(\rR\x13typeVariationAnchor\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x1a\xc4\x01\n\x11\x45xtensionFunction\x12:\n\x17\x65xtension_uri_reference\x18\x01 \x01(\rB\x02\x18\x01R\x15\x65xtensionUriReference\x12\x36\n\x17\x65xtension_urn_reference\x18\x04 \x01(\rR\x15\x65xtensionUrnReference\x12\'\n\x0f\x66unction_anchor\x18\x02 \x01(\rR\x0e\x66unctionAnchor\x12\x12\n\x04name\x18\x03 \x01(\tR\x04nameB\x0e\n\x0cmapping_type\"\x85\x01\n\x11\x41\x64vancedExtension\x12\x38\n\x0coptimization\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyR\x0coptimization\x12\x36\n\x0b\x65nhancement\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0b\x65nhancementBq\n\x12io.substrait.protoP\x01ZDgithub.com/substrait-io/substrait-protobuf/go/substraitpb/extensions\xaa\x02\x12Substrait.Protobufb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'substrait.extensions.extensions_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022io.substrait.protoP\001ZDgithub.com/substrait-io/substrait-protobuf/go/substraitpb/extensions\252\002\022Substrait.Protobuf'
  _globals['_SIMPLEEXTENSIONURI']._loaded_options = None
  _globals['_SIMPLEEXTENSIONURI']._serialized_options = b'\030\001'
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONTYPE'].fields_by_name['extension_uri_reference']._loaded_options = None
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONTYPE'].fields_by_name['extension_uri_reference']._serialized_options = b'\030\001'
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONTYPEVARIATION'].fields_by_name['extension_uri_reference']._loaded_options = None
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONTYPEVARIATION'].fields_by_name['extension_uri_reference']._serialized_options = b'\030\001'
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONFUNCTION'].fields_by_name['extension_uri_reference']._loaded_options = None
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONFUNCTION'].fields_by_name['extension_uri_reference']._serialized_options = b'\030\001'
  _globals['_SIMPLEEXTENSIONURI']._serialized_start=90
  _globals['_SIMPLEEXTENSIONURI']._serialized_end=182
  _globals['_SIMPLEEXTENSIONURN']._serialized_start=184
  _globals['_SIMPLEEXTENSIONURN']._serialized_end=272
  _globals['_SIMPLEEXTENSIONDECLARATION']._serialized_start=275
  _globals['_SIMPLEEXTENSIONDECLARATION']._serialized_end=1276
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONTYPE']._serialized_start=662
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONTYPE']._serialized_end=846
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONTYPEVARIATION']._serialized_start=849
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONTYPEVARIATION']._serialized_end=1061
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONFUNCTION']._serialized_start=1064
  _globals['_SIMPLEEXTENSIONDECLARATION_EXTENSIONFUNCTION']._serialized_end=1260
  _globals['_ADVANCEDEXTENSION']._serialized_start=1279
  _globals['_ADVANCEDEXTENSION']._serialized_end=1412
# @@protoc_insertion_point(module_scope)
