# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: substrait/extended_expression.proto
# Protobuf Python Version: 5.29.5
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    5,
    '',
    'substrait/extended_expression.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from substrait import algebra_pb2 as substrait_dot_algebra__pb2
from substrait.extensions import extensions_pb2 as substrait_dot_extensions_dot_extensions__pb2
from substrait import plan_pb2 as substrait_dot_plan__pb2
from substrait import type_pb2 as substrait_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#substrait/extended_expression.proto\x12\tsubstrait\x1a\x17substrait/algebra.proto\x1a%substrait/extensions/extensions.proto\x1a\x14substrait/plan.proto\x1a\x14substrait/type.proto\"\xb8\x01\n\x13\x45xpressionReference\x12\x37\n\nexpression\x18\x01 \x01(\x0b\x32\x15.substrait.ExpressionH\x00R\nexpression\x12\x38\n\x07measure\x18\x02 \x01(\x0b\x32\x1c.substrait.AggregateFunctionH\x00R\x07measure\x12!\n\x0coutput_names\x18\x03 \x03(\tR\x0boutputNamesB\x0b\n\texpr_type\"\xc0\x04\n\x12\x45xtendedExpression\x12,\n\x07version\x18\x07 \x01(\x0b\x32\x12.substrait.VersionR\x07version\x12S\n\x0e\x65xtension_uris\x18\x01 \x03(\x0b\x32(.substrait.extensions.SimpleExtensionURIB\x02\x18\x01R\rextensionUris\x12O\n\x0e\x65xtension_urns\x18\x08 \x03(\x0b\x32(.substrait.extensions.SimpleExtensionURNR\rextensionUrns\x12P\n\nextensions\x18\x02 \x03(\x0b\x32\x30.substrait.extensions.SimpleExtensionDeclarationR\nextensions\x12\x43\n\rreferred_expr\x18\x03 \x03(\x0b\x32\x1e.substrait.ExpressionReferenceR\x0creferredExpr\x12\x37\n\x0b\x62\x61se_schema\x18\x04 \x01(\x0b\x32\x16.substrait.NamedStructR\nbaseSchema\x12X\n\x13\x61\x64vanced_extensions\x18\x05 \x01(\x0b\x32\'.substrait.extensions.AdvancedExtensionR\x12\x61\x64vancedExtensions\x12,\n\x12\x65xpected_type_urls\x18\x06 \x03(\tR\x10\x65xpectedTypeUrlsBf\n\x12io.substrait.protoP\x01Z9github.com/substrait-io/substrait-protobuf/go/substraitpb\xaa\x02\x12Substrait.Protobufb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'substrait.extended_expression_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022io.substrait.protoP\001Z9github.com/substrait-io/substrait-protobuf/go/substraitpb\252\002\022Substrait.Protobuf'
  _globals['_EXTENDEDEXPRESSION'].fields_by_name['extension_uris']._loaded_options = None
  _globals['_EXTENDEDEXPRESSION'].fields_by_name['extension_uris']._serialized_options = b'\030\001'
  _globals['_EXPRESSIONREFERENCE']._serialized_start=159
  _globals['_EXPRESSIONREFERENCE']._serialized_end=343
  _globals['_EXTENDEDEXPRESSION']._serialized_start=346
  _globals['_EXTENDEDEXPRESSION']._serialized_end=922
# @@protoc_insertion_point(module_scope)
